@@ -4,13 +4,14 @@ import uuid
 
 
 KESTREL_CONFIG = pathlib.Path("kestrel") / "kestrel.toml"
+KESTREL_CONFIG_PATH_ENV_VAR = "KESTREL_CONFIG_PATH"
 
 
 def config_paths():
     # latter ones will override former ones
     paths = [
         # pip install with root
-        pathlib.Path("/") / KESTREL_CONFIG,
+        pathlib.Path("/etc") / KESTREL_CONFIG,
         pathlib.Path("/usr/etc") / KESTREL_CONFIG,
         pathlib.Path("/usr/local/etc") / KESTREL_CONFIG,
         # pip install in venv
@@ -25,6 +26,10 @@ def config_paths():
         pathlib.Path(os.getenv("HOME", "")) / ".config" / KESTREL_CONFIG,
     ]
 
+    dynamic_config_file = os.getenv("KESTREL_CONFIG_PATH")
+    if dynamic_config_file:
+        paths.append(dynamic_config_file)
+
     path_dedups = []
     for path in paths:
         if path not in path_dedups:
